@@ -25,6 +25,12 @@ SUPPORTED_TASKS = {
         "default": {
             "model": "mrm8488/t5-base-finetuned-common_gen",
         },
+    },
+    "k2t-new": {
+        "impl": NMPipeline,
+        "default": {
+            "model": "gagan3012/k2t-new",
+        },
     }
 }
 
