@@ -1,3 +1,5 @@
+import shutil
+
 import torch
 import numpy as np
 import pandas as pd
@@ -164,8 +166,8 @@ class LightningModel(pl.LightningModule):
         self.model = model
         self.tokenizer = tokenizer
         self.output = output
-        #self.val_acc = Accuracy()
-        #self.train_acc = Accuracy()
+        # self.val_acc = Accuracy()
+        # self.train_acc = Accuracy()
 
     def forward(self, input_ids, attention_mask, decoder_attention_mask, labels=None):
         """ forward step """
@@ -191,9 +193,7 @@ class LightningModel(pl.LightningModule):
             decoder_attention_mask=labels_attention_mask,
             labels=labels,
         )
-        # acc = self.val_acc(outputs.logits.argmax(1), labels)
         self.log("train_loss", loss, prog_bar=True, logger=True)
-        # self.log(f"train_acc", acc, prog_bar=True, logger=True)
         return loss
 
     def validation_step(self, batch, batch_size):
@@ -209,9 +209,7 @@ class LightningModel(pl.LightningModule):
             decoder_attention_mask=labels_attention_mask,
             labels=labels,
         )
-        # acc = self.val_acc(outputs.logits.argmax(1), labels)
         self.log("val_loss", loss, prog_bar=True, logger=True)
-        # self.log(f"val_acc", acc, prog_bar=True, logger=True)
         return loss
 
     def test_step(self, batch, batch_size):
@@ -435,8 +433,10 @@ class trainer:
         ]
         return preds[0]
 
-    def upload(self, model_name, hf_username):
+    def upload(self, hf_username, model_name):
         hf_password = getpass("Enter your HuggingFace password")
+        if Path('./model').exists():
+            shutil.rmtree('./model')
         token = HfApi().login(username=hf_username, password=hf_password)
         del hf_password
         model_url = HfApi().create_repo(token=token, name=model_name, exist_ok=True)
@@ -462,7 +462,7 @@ model-index:
 - name: {model_name}
 ---
         
-        <h1 align="center">keytotext</h1>
+#keytotext
 
 [![pypi Version](https://img.shields.io/pypi/v/keytotext.svg?logo=pypi&logoColor=white)](https://pypi.org/project/keytotext/)
 [![Downloads](https://static.pepy.tech/personalized-badge/keytotext?period=total&units=none&left_color=grey&right_color=orange&left_text=Pip%20Downloads)](https://pepy.tech/project/keytotext)
@@ -489,6 +489,7 @@ Potential use case can include:
         """.strip()
 
         (Path(model_repo.local_dir) / 'README.md').write_text(readme_txt)
+        self.save_model()
         commit_url = model_repo.push_to_hub()
 
         print("Check out your model at:")
